==> v0.1.86-snapshot.tar.gz: beteran-protobuf-rust/src/c2se/api/betting.rs <==
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListBettingHistoryRequest {
  #[prost(message, optional, tag = "1")]
  pub pagination: ::core::option::Option<crate::protobuf::pagination::Pagination>,
  #[prost(message, repeated, tag = "2")]
  pub sorts: ::prost::alloc::vec::Vec<crate::protobuf::pagination::Sort>,
  #[prost(message, optional, tag = "3")]
  pub search: ::core::option::Option<list_betting_history_request::Search>,
}
/// Nested message and enum types in `ListBettingHistoryRequest`.
pub mod list_betting_history_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Search {
    #[prost(string, optional, tag = "1")]
    pub member_id: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(uint64, optional, tag = "2")]
    pub vendor_id: ::core::option::Option<u64>,
    #[prost(string, optional, tag = "3")]
    pub vendor_name: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "4")]
    pub vendor_name_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(uint64, optional, tag = "5")]
    pub game_id: ::core::option::Option<u64>,
    #[prost(string, optional, tag = "6")]
    pub game_name: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "7")]
    pub game_name_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "8")]
    pub game_category: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "9")]
    pub game_category_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "10")]
    pub game_type: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "11")]
    pub game_type_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "12")]
    pub currency: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "13")]
    pub currency_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "14")]
    pub key: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "15")]
    pub key_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "16")]
    pub ref_id: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "17")]
    pub ref_id_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "18")]
    pub o_ref_id: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "19")]
    pub o_ref_id_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "20")]
    pub group_key: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "21")]
    pub group_key_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(bool, optional, tag = "22")]
    pub is_bonus: ::core::option::Option<bool>,
    #[prost(bool, optional, tag = "23")]
    pub is_promo: ::core::option::Option<bool>,
    #[prost(bool, optional, tag = "24")]
    pub is_jackpot: ::core::option::Option<bool>,
    #[prost(string, optional, tag = "25")]
    pub site_username: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "26")]
    pub site_username_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "27")]
    pub betting_type: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "28")]
    pub betting_type_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "29")]
    pub category: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "30")]
    pub category_like: ::core::option::Option<::prost::alloc::string::String>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListBettingHistoryResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<list_betting_history_response::Result>,
}
/// Nested message and enum types in `ListBettingHistoryResponse`.
pub mod list_betting_history_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, repeated, tag = "1")]
    pub betting_history: ::prost::alloc::vec::Vec<crate::models::api::betting::BettingHistoryModel>,
  }
}

==> v0.1.91-snapshot.tar.gz: beteran-protobuf-rust/src/c2se/api/betting.rs <==
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListBettingHistoryRequest {
  #[prost(message, optional, tag = "1")]
  pub pagination: ::core::option::Option<crate::protobuf::pagination::Pagination>,
  #[prost(message, repeated, tag = "2")]
  pub sorts: ::prost::alloc::vec::Vec<crate::protobuf::pagination::Sort>,
  #[prost(message, optional, tag = "3")]
  pub search: ::core::option::Option<list_betting_history_request::Search>,
}
/// Nested message and enum types in `ListBettingHistoryRequest`.
pub mod list_betting_history_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Search {
    #[prost(string, optional, tag = "1")]
    pub member_id: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(uint64, optional, tag = "2")]
    pub vendor_id: ::core::option::Option<u64>,
    #[prost(uint64, repeated, tag = "3")]
    pub vendor_ids: ::prost::alloc::vec::Vec<u64>,
    #[prost(string, optional, tag = "4")]
    pub vendor_name: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "5")]
    pub vendor_name_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(uint64, optional, tag = "6")]
    pub game_id: ::core::option::Option<u64>,
    #[prost(uint64, repeated, tag = "7")]
    pub game_ids: ::prost::alloc::vec::Vec<u64>,
    #[prost(string, optional, tag = "8")]
    pub game_name: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "9")]
    pub game_name_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "10")]
    pub game_category: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "11")]
    pub game_category_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "12")]
    pub game_type: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "13")]
    pub game_type_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "14")]
    pub currency: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "15")]
    pub currency_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "16")]
    pub key: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "17")]
    pub key_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "18")]
    pub ref_id: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "19")]
    pub ref_id_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "20")]
    pub o_ref_id: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "21")]
    pub o_ref_id_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "22")]
    pub group_key: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "23")]
    pub group_key_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(bool, optional, tag = "24")]
    pub is_bonus: ::core::option::Option<bool>,
    #[prost(bool, optional, tag = "25")]
    pub is_promo: ::core::option::Option<bool>,
    #[prost(bool, optional, tag = "26")]
    pub is_jackpot: ::core::option::Option<bool>,
    #[prost(string, optional, tag = "27")]
    pub site_username: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "28")]
    pub site_username_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "29")]
    pub betting_type: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "30")]
    pub betting_type_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "31")]
    pub category: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "32")]
    pub category_like: ::core::option::Option<::prost::alloc::string::String>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListBettingHistoryResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<list_betting_history_response::Result>,
}
/// Nested message and enum types in `ListBettingHistoryResponse`.
pub mod list_betting_history_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, repeated, tag = "1")]
    pub betting_history: ::prost::alloc::vec::Vec<crate::models::api::betting::BettingHistoryModel>,
  }
}
